# Frametree - BIDS
[![Tests](https://github.com/arcanaframework/frametree-bids/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/arcanaframework/frametree-bids/actions/workflows/ci-cd.yml)
[![Codecov](https://codecov.io/gh/arcanaframework/frametree-bids/branch/main/graph/badge.svg?token=UIS0OGPST7)](https://codecov.io/gh/arcanaframework/frametree-bids)
[![Python versions](https://img.shields.io/pypi/pyversions/frametree-bids.svg)](https://pypi.python.org/pypi/frametree-bids/)
[![Latest Version](https://img.shields.io/pypi/v/frametree-bids.svg)](https://pypi.python.org/pypi/frametree-bids/)
[![Documentation Status](https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat)](https://arcanaframework.github.io/frametree)

An extension of [FrameTree](http://frametree.readthedocs.io) to work with Brain Imaging Data Structure (BIDS) datasets and apps

## Quick Installation

This extension can be installed for Python 3 using *pip*:

```
$ pip3 install frametree-bids
```

This will also install the core FrameTree package and any required dependencies.

## License

This work is licensed under a [Creative Commons Attribution 4.0 International License](http://creativecommons.org/licenses/by/4.0/).

[![Creative Commons Attribution 4.0 International License](https://i.creativecommons.org/l/by/4.0/88x31.png)](http://creativecommons.org/licenses/by/4.0/)
